/*
 *
 *	Headerfile of quota interactions with system - filenames, fstab...
 *
 */

#ifndef _QUOTASYS_H
#define _QUOTASYS_H

#include <sys/types.h>

#define MAXFILENAMELEN 128	/* Maximal length of filename */
#define MAXFSTYPELEN 32		/* Maximal length of filesystem type */
#define MAXDEVLEN 64		/* Maximal length of device name */
#define MAXNAMELEN 64		/* Maximal length of user/group name */
#define MAXMNTPOINTS 64		/* Maximal number of mountpoints passed by user */
#define MAXTIMELEN 40		/* Maximal length of time string */

/* Flags used for internal passing of types */
#define QS_USRQUOTA 1
#define QS_GRPQUOTA 2

/*
 *	Exported functions
 */
/* Convert userspace quotatype to kernel one */
extern int user2kernquota(int);
/* Convert kernel quotatype to userspace one */
extern int kern2userquota(int);
/* Convert quota type to written form */
extern char *type2name(int);
/* Get name of quotafile */
extern void get_qfname(char *, int, char *);
/* Init structures for searching in mount informations */
extern void init_mount(char **, int);
/* Return next matching mountpoint */
extern int next_mount(int, char *, char *, char *);
/* Free all structures used for searching */
extern void free_mount(void);
/* Convert username to uid */
extern uid_t name2uid(char *);
/* Convert groupname to gid */
extern gid_t group2gid(char *);
/* Convert uid to username */
extern void uid2name(uid_t, char *);
/* Convert gid to groupname */
extern void gid2group(gid_t, char *);
/* Convert time difference between given time and current time to printable form */
extern void difftime2str(time_t, char *);
/* Convert time to printable form */
extern void time2str(time_t, char *);

#endif	/* _QUOTASYS_H */
